@@ -4,14 +4,15 @@ use strict;
 use warnings;
 use parent "Plack::Middleware";
 
-our $VERSION = "0.01";
+our $VERSION = "0.02";
 
 sub call {
     my ($self, $env) = @_;
 
     local %ENV = %ENV;
     for my $key (keys %$self) {
-        $ENV{$key} = $env->{ $self->{$key} };
+        $ENV{$key} = $env->{ $self->{$key} }
+            if exists $env->{$self->{$key}};
     }
     $self->app->($env);
 }
